@@ -10,9 +10,7 @@ use warnings;
 use base qw( Device::Chip::Base::RegisteredI2C );
 Device::Chip::Base::RegisteredI2C->VERSION( '0.10' );
 
-use Future::AsyncAwait 0.13; # list-context bugfix
-
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Data::Bitfield 0.02 qw( bitfield boolfield enumfield );
 
@@ -99,13 +97,14 @@ bitfield { format => "bytes-BE" }, CONFIG =>
    COMP_LAT  => boolfield(2),
    COMP_QUE  => enumfield(0, qw( 1 2 4 DIS ));
 
-async sub read_config
+sub read_config
 {
    my $self = shift;
 
-   my $bytes = await $self->cached_read_reg( REG_CONFIG, 1 );
-
-   return $self->{config} = { unpack_CONFIG( $bytes ) };
+   $self->cached_read_reg( REG_CONFIG, 1 )->then( sub {
+      my ( $bytes ) = @_;
+      Future->done( $self->{config} = { unpack_CONFIG( $bytes ) } );
+   });
 }
 
 =head2 change_config
@@ -117,18 +116,20 @@ their existing values.
 
 =cut
 
-async sub change_config
+sub change_config
 {
    my $self = shift;
    my %changes = @_;
 
-   my $config = $self->{config} // await $self->read_config;
+   ( defined $self->{config} ? Future->done( $self->{config} ) :
+         $self->read_config )->then( sub {
+      my ( $config ) = @_;
+      %$config = ( %$config, %changes );
 
-   %$config = ( %$config, %changes );
+      delete $self->{fullscale_f} if exists $changes{PGA};
 
-   delete $self->{fullscale_f} if exists $changes{PGA};
-
-   await $self->cached_write_reg( REG_CONFIG, pack_CONFIG( %$config ) );
+      $self->cached_write_reg( REG_CONFIG, pack_CONFIG( %$config ) );
+   });
 }
 
 =head2 trigger
@@ -140,14 +141,15 @@ reading of the currently-selected input channel when in single-shot mode.
 
 =cut
 
-async sub trigger
+sub trigger
 {
    my $self = shift;
 
-   my $config = await $self->read_config;
-
-   # Not "cached" as OS is a volatile bit
-   await $self->write_reg( REG_CONFIG, pack_CONFIG( %$config, OS => 1 ) );
+   $self->read_config->then( sub {
+      my ( $config ) = @_;
+      # Not "cached" as OS is a volatile bit
+      $self->write_reg( REG_CONFIG, pack_CONFIG( %$config, OS => 1 ) );
+   });
 }
 
 =head2 read_adc
@@ -163,13 +165,14 @@ integer. To convert this into voltage use the L</read_adc_voltage> method.
 
 =cut
 
-async sub read_adc
+sub read_adc
 {
    my $self = shift;
 
-   my $bytes = await $self->read_reg( REG_RESULT, 1 );
-
-   return unpack "S>", $bytes;
+   $self->read_reg( REG_RESULT, 1 )->then( sub {
+      my ( $bytes ) = @_;
+      Future->done( unpack "S>", $bytes );
+   });
 }
 
 sub _fullscale
@@ -193,14 +196,15 @@ configuration option to scale it.
 
 =cut
 
-async sub read_adc_voltage
+sub read_adc_voltage
 {
    my $self = shift;
 
-   my $f = Future->needs_all( $self->_fullscale, $self->read_adc );
-   my ( $fullscale, $reading ) = await $f;
+   Future->needs_all( $self->_fullscale, $self->read_adc )->then( sub {
+      my ( $fullscale, $reading ) = @_;
 
-   return ( $reading * $fullscale ) / ( 1 << 15 );
+      Future->done( ( $reading * $fullscale ) / ( 1 << 15 ) );
+   });
 }
 
 =head1 AUTHOR
