@@ -9,9 +9,7 @@ use strict;
 use warnings;
 use base qw( Device::Chip );
 
-use Future::AsyncAwait;
-
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use constant PROTOCOL => "SPI";
 
@@ -65,33 +63,33 @@ other fields will be provided.
 
 =cut
 
-async sub read_adc
+sub read_adc
 {
    my $self = shift;
+   $self->protocol->readwrite( "\x00" x 4 )->then( sub {
+      my ( $bytes ) = @_;
+      my $value = unpack "L>", $bytes;
 
-   my $bytes = await $self->protocol->readwrite( "\x00" x 4 );
+      if( $value & 1<<30 ) {
+         return Future->fail( "Expected dummy bit LOW" );
+      }
+      if( $value & 1<<31 ) {
+         return Future->done( { EOC => 0 } );
+      }
 
-   my $value = unpack "L>", $bytes;
+      my $sig = ( $value & 1<<29 ) > 0;
+      my $exr = ( $value & 1<<28 ) > 0;
 
-   if( $value & 1<<30 ) {
-      return Future->fail( "Expected dummy bit LOW" );
-   }
-   if( $value & 1<<31 ) {
-      return Future->done( { EOC => 0 } );
-   }
+      $value &= ( 1<<28 )-1;
+      $value >>= 4;
 
-   my $sig = ( $value & 1<<29 ) > 0;
-   my $exr = ( $value & 1<<28 ) > 0;
-
-   $value &= ( 1<<28 )-1;
-   $value >>= 4;
-
-   return {
-      EOC   => 1,
-      SIG   => $sig,
-      EXR   => $exr,
-      VALUE => $value,
-   };
+      return Future->done( {
+         EOC   => 1,
+         SIG   => $sig,
+         EXR   => $exr,
+         VALUE => $value,
+      } );
+   });
 }
 
 =head1 AUTHOR
